/v1/projects/{project_id}/dynamips/devices/{device_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips device »

# /v1/projects/{project_id}/dynamips/devices/{device_id}

Contents

- /v1/projects/{project_id}/dynamips/devices/{device_id}
  - GET /v1/projects/{project_id}/dynamips/devices/{device_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/projects/{project_id}/dynamips/devices/{device_id}
    - Parameters
    - Response status codes
    - Input
      - Types
        - EthernetSwitchPort
      - Body
    - Output
  - DELETE /v1/projects/{project_id}/dynamips/devices/{device_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}/dynamips/devices/{device_id}

Get a Dynamips device instance

### Parameters

- device_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
device_id | ✔ | string | Dynamips router instance UUID
mappings |  | object |
name | ✔ | string | Dynamips device instance name
ports |  | array |
project_id | ✔ | string | Project UUID

## PUT /v1/projects/{project_id}/dynamips/devices/{device_id}

Update a Dynamips device instance

### Parameters

- device_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

#### Types

##### EthernetSwitchPort

Ethernet switch port

Name | Mandatory | Type | Description
--- | --- | --- | ---
port | ✔ | integer | Port number
type | ✔ | enum | Possible values: access, dot1q, qinq
vlan | ✔ | integer | VLAN number

#### Body

Name | Mandatory | Type | Description
--- | --- | --- | ---
name |  | string | Dynamips device instance name
ports |  | array |

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
device_id | ✔ | string | Dynamips router instance UUID
mappings |  | object |
name | ✔ | string | Dynamips device instance name
ports |  | array |
project_id | ✔ | string | Project UUID

## DELETE /v1/projects/{project_id}/dynamips/devices/{device_id}

Delete a Dynamips device instance

### Parameters

- device_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips device »